@@ -1,13 +1,14 @@
 import logging
+from copy import deepcopy
 from typing import Dict, List, Union, Tuple
 
 from models_manager.connect import Connect
 from models_manager.manager.exeptions import ModelDoesNotExists, ModelOperationError
-from models_manager.manager.field import Field
+from models_manager.manager.field.field import Field
 from models_manager.manager.query.builder import get_query
 from models_manager.manager.query_set import QuerySet
 from models_manager.providers.provider import Provider
-from models_manager.utils import where, normalize_model, serializer, dump_value, dump_fields, binding
+from models_manager.utils import normalize_model, serializer, dump_value, dump_fields, binding
 
 connection = Connect()
 
@@ -36,6 +37,13 @@ class ModelManager:
     def _lazy_query(self):
         return getattr(connection, self._database, None)
 
+    def apply_values(self, **kwargs):
+        for _, field in self.__fields_as_original(json_key=False).items():
+            value = kwargs.get(field.json, None)
+
+            if value is not None:
+                field.value = value
+
     def __resolve_attrs(self, **kwargs):
         """
         Method that helps to keep consistency of attr
@@ -69,7 +77,7 @@ class ModelManager:
                     logging.error(f'Unable to resolve field "{field}". Skipped')
 
             if isinstance(value, Field) and not field.startswith('_meta'):
-                setattr(self, f'_meta__{field}', value)
+                setattr(self, f'_meta__{field}', deepcopy(value))
                 continue
 
             setattr(self, field, value)
@@ -137,7 +145,7 @@ class ModelManager:
 
         return type(self._model, self._mro, {**self.__dict__, **(result or {})})()
 
-    def fields(self, json_key: bool) -> Dict[str, Field]:
+    def fields(self, json_key: bool = True) -> Dict[str, Field]:
         return self.__fields_as_original(json_key)
 
     @property
@@ -151,7 +159,7 @@ class ModelManager:
             MyModel.manager.to_json -> {'id': 1, 'username': 'some'}
         """
         return {
-            value.json: value.get_default
+            value.json: value.value
             for value in self.__fields_as_original().values()
             if value.json is not None
         }
@@ -338,7 +346,7 @@ class ModelManager:
 
         return fields
 
-    def get(self, as_json=True, **kwargs):
+    def get(self, *args, as_json=True, **kwargs):
         """
         Getting db instance
 
@@ -348,13 +356,12 @@ class ModelManager:
         """
         model = normalize_model(self._model)
         sql = f'SELECT * FROM "{model}"'
-        values = tuple(kwargs.values())
 
-        if kwargs:
-            bind = ' AND '.join([f'"{model}"."{field}" = %s' for field in kwargs])
-            sql += f' WHERE {bind};'
+        query = get_query(model, *args, **kwargs)
+        if query:
+            sql += f' WHERE {query}'
 
-        cursor = self._lazy_query(sql, values)
+        cursor = self._lazy_query(sql)
         result = serializer(cursor, many=False)
 
         if not result:
@@ -443,7 +450,7 @@ class ModelManager:
 
         return self.__as_json(as_json, result)
 
-    def is_exists(self, operand='AND', operator='=', **kwargs) -> bool:
+    def is_exists(self, *args, **kwargs) -> bool:
         """
         This method used to check if object exists in database.
         Will return True if object exists else will return False.
@@ -456,15 +463,15 @@ class ModelManager:
         """
         model = normalize_model(self._model)
         sql = f'SELECT NULL FROM "{model}"'
-        values = tuple(kwargs.values())
+        query = get_query(model, *args, **kwargs)
 
-        if kwargs:
-            sql += where(model, operand, operator, **kwargs)
+        if query:
+            sql += f' WHERE {query}'
 
-        cursor = self._lazy_query(sql, values)
+        cursor = self._lazy_query(sql)
         return bool(cursor.fetchall())
 
-    def get_or_create(self, as_json=True, **kwargs):
+    def get_or_create(self, *args, as_json=True, **kwargs):
         """
         Will return existing instance if such exists else
         will create such instance and return it.
@@ -473,6 +480,6 @@ class ModelManager:
         MyModel.manager.get_or_create(name='some') -> {'id': 1, 'name': 'some'}
         """
         try:
-            return self.get(as_json, **kwargs)
+            return self.get(as_json=as_json, *args, **kwargs)
         except ModelDoesNotExists:
             return self.create(as_json, **kwargs)
